%---------------------------------------------------------------------  
% function [] = FT_help(help_name)
%
% Prints list of functions & descriptions matching input
% by name, keyword or category
%
% Part of the SimTools package, http://www.gwoptics.org/simtools
% Robert Unwin, Andreas Freise 11.02.11 
%---------------------------------------------------------------------  

function [] = FT_help(help_name, show_path)
  fprintf('\n');
  
  % print usage when no input argument is given
  if (nargin==0)
    print_usage;
    return;
  end

  if (nargin<2)
    show_path=false;
  end
      
  % open data files
  help_info_out;
  help_info_key;
  help_info_cat;
  
  if (strcmp(help_name,'all'))
    fprintf('Displaying all entries:\n\n');
    nfiles = length(index);
    for i=1:nfiles
      fprintf('  %s',index(i).name);
      fprintf(': ');
      ndesc = length(index(i).description);
      for j=1:ndesc
        fprintf(cell2mat(index(i).description(j)));
        fprintf('\n  ');
      end
      print_path(index(i).path,show_path);
      fprintf('\n');
    end
    return
  end
    
  if (strcmp(help_name,'key'))
    fprintf('Possible key words:\n\n');
    nkeywords = length(key);
    txt=' ';
    slength=0;
    first=true;
    for i=1:nkeywords
      if (~strcmp(key(i).word,'(no marker)') && ~strcmp(key(i).word,'(no keyword)')) 
        if (~first)
          txt=[txt,', '];
        end
        first=false;
        txt=[txt,lower(key(i).word)];
        slength=slength+length(key(i).word)+2;
        if (slength>60)
          fprintf('%s\n',txt);
          txt=' ';
          first=true;
          slength=0;
        end
      end
    end
      fprintf('%s\n',txt);
    return
  end
    
  Q = true; % define Boolean to flag whether match has been found

  % print function help if input argument is a full function name
  nfiles = length(index);
  for i=1:nfiles
    if strcmp(index(i).name,help_name);
      Q = false;
      fprintf('Function "%s":\n',help_name);
      ndesc = length(index(i).description);
      for j=1:ndesc
        fprintf(cell2mat(index(i).description(j)));
        fprintf('\n');
      end
      fprintf('\n');
      help(help_name);
      print_path(index(i).path,show_path);
      fprintf('\n');
    end
  end

 shown=[];

  % check if help name is a keyword
  nkeywords = length(key);
  files = [];
  for i=1:nkeywords
    if strfind(lower(key(i).word),lower(help_name));
      Q = false;
      files = key(i).files;
      shown=[shown, files];
      break;
    end
  end

  if ~isempty(files)
    nfiles = length(files);
    fprintf('----------------------------------------------------------\n');
    fprintf('Displaying files containing keyword, "%s":\n\n',help_name);
    for i=1:nfiles
      fprintf(' - %s',index(files(i)).name);
      fprintf(': ');
      ndesc = length(index(files(i)).description);
      for j=1:ndesc
        if (j~=1)
          fprintf('   ');
        end
        fprintf(cell2mat(index(files(i)).description(j)));
        fprintf('\n');
      end
       print_path(index(i).path,show_path);
    end
    fprintf('\n');
  end


  % check if help name is a category
  ncatwords = length(category);
  files = [];
  for i=1:ncatwords
    if strfind(lower(category(i).word),lower(help_name));
      Q = false;
      files = category(i).files;
      break;
    end
  end

  if ~isempty(files)
    nfiles = length(files);
    fprintf('----------------------------------------------------------\n');
    fprintf('Displaying files in category, "%s":\n\n',help_name);
    for i=1:nfiles
      if (isempty(find(files(i)==shown)))
        ndesc = length(index(files(i)).description);
        fprintf(' - %s',index(files(i)).name);
        fprintf(': ');
        print_path(index(i).path,show_path);
        for j=1:ndesc
          if (j~=1)
            fprintf('   ');
          end
          fprintf(cell2mat(index(files(i)).description(j)));
          fprintf('\n');
        end
      end
    end
    fprintf('\n');
  end
  
  if Q
    fprintf('*** No matches found\n\n');
    print_usage;
  end
end

function print_path(pathstring,show_path)
  if (show_path)
    fprintf('%s\n',pathstring);
  end
end
  
function []=print_usage()
  fprintf('-------------------------------------------------------------------------\n');
  fprintf('SimTools 0.6, Andreas Freise, 14.02.2011         Matlab utility functions\n');
  fprintf('\n');
  fprintf('Usage: FT_help(help_topic, [true])\n\n');
  fprintf('use the string "help_topic" to select a topic from the following list:\n\n');
  fprintf(' - [keyword]: lists all functions with matching keyword\n');
  fprintf(' - [category]: lists all functions in matching category\n');
  fprintf(' - [filename]: prints a description of the function matching the filename\n');
  fprintf(' - ''key'': lists all available keywords\n');
  fprintf(' - ''all'': lists all available function from the SimTools package\n');
  fprintf('\n');
  fprintf('The second optional argument "true" causes the display of path information.\n');
  fprintf('\n');
end
