% Computes a varying aperture size of a mirror and reflects a beam from it,
% the reflected power is compared against the analytic solution to the
% power the should be reflected for different maxtem

clear all;
delete('*.bak');
delete('*.knm');
delete('*.bin');
delete('*.map');
delete('dump*.dat');

FT=FT_init_Finesse();
FT_check_for_kat_binary(FT);

% analytic power loss from circular aperture - Siegmann, Lasers
Analytic = @(r_w, Ptot) Ptot.*(1 - exp(-2 .* (r_w).^2 ));

% ratio between aperture radius and beam size
r = linspace(1e-5, 2e-3, 21)';
w = 1e-3;

[blk] = FT_read_blocks_from_file('aperture_test.kat');

maxtem = [0 2 5 10];
i = 1;
katname = 'aperture_test_blocks.kat';
results = zeros(length(maxtem), length(r));

for mt = maxtem
    cmds = sprintf('xaxis m1 r_ap lin %g %g %i\nmaxtem %i', min(r), max(r), length(r)-1, mt);
    outbl(1) = FT_copy_block(blk,'aptest');
    outbl(2) = FT_create_new_block('commands');
    outbl(2) = FT_add_line_to_block(outbl(2), cmds);
    
    FT_write_blocks_into_file(outbl,katname);

    Run(i)=FT_create_new_kat_run();
    Run(i).filename=katname;
    fprintf('Running maxtem=%i ...\n',mt);
    Run(i)=FT_run_kat_simulation(FT,Run(i),1);

    FT_kat_clean(Run(i));
    
    results(i,:) = Run(i).y;
    lgs{i} = sprintf('maxtem=%i',mt);
    i = i+1;
end

lgs{i} = 'Analytic';

%%
r_w = r./w;
h = figure();
subplot(2,1,1);
plot( r_w, results,r_w, Analytic(r_w,1),'k--');
legend(lgs,'location','best');
ylim([0 1.1]);
xlabel('r/w');
ylabel('P_{ref}');
title('Reflected power from mirror with aperture r and beam size w');
subplot(2,1,2);
relerr = abs(bsxfun(@rdivide, bsxfun(@minus,Analytic(r_w,1),results'), Analytic(r_w,1)));
semilogy(r_w, relerr);
ylim([min(min(relerr)) 3*max(max(relerr))]);
%legend(lgs(1:(end-1)),'location','best');
xlabel('r/w');
ylabel('Relative error');
title({'Relative error between computed reflected power','from apertured mirror and analytic'});
