% Apertures can be set in 2 ways, an absorption map or using the attr
% command. Both involve integrating the coupling coefficients equation, but
% the map can have be more or less accurate

clear all;
delete('*.bak');
delete('*.knm');
delete('*.bin');
delete('*.map');
delete('dump*.dat');
FT=FT_init_Finesse();
FT_check_for_kat_binary(FT);

% analytic power loss from circular aperture - Siegmann, Lasers
Analytic = @(r_w, Ptot) Ptot.*(1 - exp(-2 .* (r_w).^2 ));
 
% aperture radii
r = [2e-3 2.5e-3];

% gridsize of aperture map
N = [100 200 400 800 1200];
    
w = 1e-3;

[blk] = FT_read_blocks_from_file('aperture_test.kat');
% do maxtem backwards as the others are already computed when doing the
% highest first and saving with the kmn command
maxtem = [8 6 4 2 0];

katname = 'aperture_test_blocks.kat';
result_map = zeros(length(r),length(N),length(maxtem));
result_attr = zeros(length(r),length(maxtem));

ir = 0;

for r_ = r
    ir = ir+1;
    in = 0;
    
    for N_ = N
        in = in+1;
        imt = 0;
        
        mapfname = sprintf('apmap_%g_N_%i.map', r_, N_);
        FT_write_aperture_map(r_, 2*r_, N_, mapfname);
        
        for mt = maxtem
            imt = imt+1;
            
            outbl(1) = FT_copy_block(blk,'aptest');
            outbl(2) = FT_create_new_block('commands');
            outbl(2) = FT_add_line_to_block(outbl(2), sprintf('noxaxis\nmaxtem %i', mt));
            outbl(3) = FT_create_new_block('maps');
            outbl(3) = FT_add_line_to_block(outbl(3), sprintf('map m1 %s', mapfname));
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 integration_method 3');
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 interpolation_method 1');
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 save_kmn_binary 1');
            outbl(3) = FT_add_line_to_block(outbl(3), sprintf('kmn m1 kmn_%s', mapfname));
            
            FT_write_blocks_into_file(outbl,katname);

            fprintf('Running maxtem=%i, N=%i, R=%g with map...\n', mt, N_, r_);
            Run = FT_create_new_kat_run();
            Run.filename=katname;
            Run = FT_run_kat_simulation(FT,Run,1);
            FT_kat_clean(Run);

            result_map(ir,in,imt) = Run.y;
            
            if in == 1
                outbl(1) = FT_copy_block(blk,'aptest');
                outbl(2) = FT_create_new_block('commands');
                outbl(2) = FT_add_line_to_block(outbl(2), sprintf('noxaxis\nmaxtem %i', mt));
                outbl(3) = FT_create_new_block('maps');
                outbl(3) = FT_add_line_to_block(outbl(3), sprintf('attr m1 r_ap %g', r_));

                FT_write_blocks_into_file(outbl,katname);

                fprintf('Running maxtem=%i, N=%i, R=%g with aperture...\n', mt, N_, r_);
                Run = FT_create_new_kat_run();
                Run.filename=katname;
                Run = FT_run_kat_simulation(FT,Run,1);
                FT_kat_clean(Run);

                result_attr(ir,imt) = Run.y;
            end
        end
    end
end

%% Matlab aperture knm compute



%%
r_w = r./w;
A = Analytic(r_w, 1);

figure(1);
rr=1;
mm=3;
plot(N, squeeze(result_map(rr,:,:)), N, ones(length(N),1)*result_attr(rr,length(maxtem)-mm),'y--',N,ones(length(N),1)*A(r_w(rr)),'k--');
lgs = cellstr(strcat('maxtem=',num2str(maxtem')));
lgs(length(lgs)+1) = cellstr('r_{ap} Attribute');
lgs(length(lgs)+1) = cellstr('Analytic');
legend(lgs,'location','EastOutside');
xlim([min(N) max(N)]);
ylim([0.9991 1.00005]);
xlabel('N, size of aperture map - NxN');
ylabel('Reflected Power [W]');
title(sprintf('Normalised reflected power from apertured mirror. Map vs. r_{ap} vs Analytic. r/\\omega=%g',r_w(rr)));

%%
figure('Position',[0,0, 1000,500]);
movegui('center') 
ir = 0;
for r_ = r
    ir = ir+1;
    subplot(1,2,ir);
    plot(N, squeeze(abs( result_map(ir,:,:) - Analytic(r_w(ir),1) ))./1e-6, N, squeeze(abs( ones(1,length(N)).*result_attr(ir,1) - Analytic(r_w(ir),1) ))./1e-6,'k--');
    xlabel('N, size of aperture map - NxN');
    ylabel('Absolute error [ppm]');
    title(sprintf('Aperture with map error with analytic, r/\\omega=%g',r(ir)/w));
    pbaspect([1 1 1]);
    lgs = cellstr(strcat('maxtem=',num2str(maxtem')));
    lgs(length(lgs)+1) = cellstr('r_{ap} Attribute');
    legend(lgs,'location','Best');
    xlim([min(N) max(N)]);
end

%plotall('aperture_abs_erro_N_vs_maxtem_0.99.9-170-g12a83ac',20,10);