clear all;
delete('*.bak');
delete('*.knm');
delete('*.bin');
delete('*.map');
delete('dump*.dat');

FT=FT_init_Finesse();
FT_check_for_kat_binary(FT);

% analytic power loss from circular aperture - Siegmann, Lasers
Analytic = @(r_w, Ptot) Ptot.*(1 - exp(-2 .* (r_w).^2 ));
 
% aperture radii
r = [2e-3 2.5e-3];

% gridsize of aperture map
N = [100 400 1200];
    
g = FT_init_gauss_param(1064e-9,1,'w0',1e-3,'z',0);

w = 1e-3;

[blk] = FT_read_blocks_from_file('aperture_test.kat');
% do maxtem backwards as the others are already computed when doing the
% highest first and saving with the kmn command
maxtem = [2 0];

katname = 'aperture_test_blocks.kat';
result_map = zeros(length(r),length(N),length(maxtem));
result_matlab = zeros(length(r),length(maxtem));

ir = 0;

for r_ = r
    ir = ir+1;
    in = 0;
    
    for N_ = N
        in = in+1;
        imt = 0;
        
        mapfname = sprintf('apmap_%g_N_%i.map', r_, N_);
        map = FT_write_aperture_map(r_, 2*r_, N_, mapfname);
        
        for mt = maxtem
            imt = imt+1;
            
            if in == 1
                K = FT_map_knm(map, g, g, mt, 1e-4,true);
                result_matlab(ir,imt) = sum(sum(K.*conj(K)));
            end
            
            outbl(1) = FT_copy_block(blk,'aptest');
            outbl(2) = FT_create_new_block('commands');
            outbl(2) = FT_add_line_to_block(outbl(2), sprintf('noxaxis\nmaxtem %i', mt));
            outbl(3) = FT_create_new_block('maps');
            outbl(3) = FT_add_line_to_block(outbl(3), sprintf('map m1 %s', mapfname));
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 integration_method 3');
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 interpolation_method 2');
            outbl(3) = FT_add_line_to_block(outbl(3), 'conf m1 save_kmn_binary 1');
            outbl(3) = FT_add_line_to_block(outbl(3), sprintf('kmn m1 kmn_%s', mapfname));
            
            FT_write_blocks_into_file(outbl,katname);

            fprintf('Running maxtem=%i, N=%i, R=%g with map...\n', mt, N_, r_);
            Run = FT_create_new_kat_run();
            Run.filename=katname;
            Run = FT_run_kat_simulation(FT,Run,1);
            FT_kat_clean(Run);

            result_map(ir,in,imt) = Run.y;
        end
    end
end


%%
r_w = r./w;
A = Analytic(r_w, 1);

figure();
rr=1;
mm=1;
plot(N, squeeze(result_map(rr,:,:)), N, ones(length(N),1)*result_matlab(rr,length(maxtem)-mm),'y--',N,ones(length(N),1)*A(r_w(rr)),'k--');
lgs = cellstr(strcat('maxtem=',num2str(maxtem')));
lgs(length(lgs)+1) = cellstr('r_{ap} Attribute');
lgs(length(lgs)+1) = cellstr('Analytic');
legend(lgs,'location','EastOutside');
xlim([min(N) max(N)]);
ylim([0.9991 1.00005]);
xlabel('N, size of aperture map - NxN');
ylabel('Reflected Power [W]');
title(sprintf('Normalised reflected power from apertured mirror. Map vs. r_{ap} vs Analytic. r/\\omega=%g',r_w(rr)));

