% Computes a varying aperture size of a mirror and reflects a beam from it,
% the reflected power is compared against the analytic solution to the
% power the should be reflected for different maxtem

fprintf('This script takes a long time!!! 8 hours or more...\n');

clear all;
delete('*.bak');
delete('*.knm');
delete('*.bin');
delete('*.map');
delete('dump*.dat');

FT=FT_init_Finesse();
FT_check_for_kat_binary(FT);

% analytic power loss from circular aperture - Siegmann, Lasers
Analytic = @(r_w, Ptot) Ptot.*(1 - exp(-2 .* (r_w).^2 ));

% ratio between aperture radius and beam size
r = linspace(1e-5, 2e-3, 11)';
w = 1e-3;

[blk] = FT_read_blocks_from_file('aperture_test.kat');

maxtem = [0 2 5];
i = 1;
katname = 'aperture_test_blocks.kat';
results = zeros(length(maxtem), length(r));

%%
for mt = maxtem
    ir = 0;
    
    for rr = r'
        ir = ir +1;
        g = FT_init_gauss_param(1064e-9,1,'w0',1e-3,'z',0);
        map = FT_write_aperture_map(r(ir), 2*r(ir), 1000);
        K = FT_map_knm(map, g, g, mt, 1e-5,true);
        result_matlab(ir,i) = sum(sum(K.*conj(K)));
    end

    cmds = sprintf('xaxis m1 r_ap lin %g %g %i\nmaxtem %i', min(r), max(r), length(r)-1, mt);
    outbl(1) = FT_copy_block(blk,'aptest');
    outbl(2) = FT_create_new_block('commands');
    outbl(2) = FT_add_line_to_block(outbl(2), cmds);
    
    FT_write_blocks_into_file(outbl,katname);

    Run(i)=FT_create_new_kat_run();
    Run(i).filename=katname;
    fprintf('Running maxtem=%i ...\n',mt);
    Run(i)=FT_run_kat_simulation(FT,Run(i),1);

    FT_kat_clean(Run(i));
    
    results(i,:) = Run(i).y;
    lgs{i} = sprintf('maxtem=%i',mt);
    i = i+1;
end


%%
r_w = r./w;
h = figure();

lgs{i+1} = 'maxtem=0 (Matlab)';
lgs{i+2} = 'maxtem=2 (Matlab)';
lgs{i+3} = 'maxtem=5 (Matlab)';

plot( r_w, results,r_w, Analytic(r_w,1),'k--',r_w, result_matlab,'--');
legend(lgs,'location','best');
ylim([0 1.05]);
xlabel('r/w');
ylabel('P_{ref}');
title('Reflected power from mirror with aperture r and beam size w');
