%--------------------------------------------------------------------------
% function [map] = FT_create_elliptical_aperture_map(D,alphax,alphay,realsize,gridsize)
%
% A function for Matlab which creates an elliptical aperture map in the
% standard map format.  The function works to create the elliptical
% aperture seen by a beam when a mirror is under a certian angle. (for a
% circle use alphax=alphay=0).
%
% D:        Mirror diameter [m]
% alphax:   Angle of incidence (x direction) [degrees]
% alphay:   Angle of incidence (y direction) [degrees]
% realsize: Overall square size of map [m]
% gridsize: Number of x and y points.
%
% Charlotte Bond    08.08.2011
%--------------------------------------------------------------------------
%

function [map] = FT_create_elliptical_aperture_map(D,alphax,alphay,realsize,gridsize)

    % Find ellipse dimensions
    a=D*cos(alphax*pi/180)/2;
    b=D*cos(alphay*pi/180)/2;
    
    mapname=sprintf('aperture_map_%gmm_%gmm',round(a*1000),round(b*1000));
    
    % Type 1: absorption map
    % Field 0: effects both transmitted and reflected light
    type=1;
    field=0;
    
    scaling=1;
    
    % Define grid
    mygrid = FT_init_grid(gridsize,gridsize,realsize,realsize,0,0);
    data = zeros(mygrid.ypoints,mygrid.xpoints);
    
    % Fill in aperture map for ellipse, i.e. 1 (total absoprtion) outside
    % ellipse and 0 (no absortion) inside it.
    ellipse = (mygrid.X.^2/a^2)+ (mygrid.Y.^2/b^2);    
    idx1 = find(ellipse>1);
    data(idx1) = 1;
    
    x0 = (gridsize+1)/2;
    y0 = (gridsize+1)/2;
    
    % Create new map
    map=FT_new_surface_map(mapname,data,type,field,x0,y0,mygrid.xstep,mygrid.ystep,scaling);

end

