%--------------------------------------------------------------------------
% function [mygrid] = FT_create_grid_for_map(map)
%
% Function for Matlab which creates a grid structure (see FT_init_grid.m)
% coresponding to a mirror map (see FT_new_surface_map.m).
%
% map:      Mirror map in the standard structure
%
% mygrid:   Grid structure containing data about the grid/axes etc.
%
% Charlotte Bond    30.04.2013
%--------------------------------------------------------------------------
%

function [mygrid] = FT_create_grid_for_map(map)
    
    % Get arguments for grid from map
    [ypoints,xpoints] = size(map.data);
    xsize = xpoints*map.xstep;
    ysize = ypoints*map.ystep;
    xoffset = ((xpoints+1)/2-map.x0)*map.xstep;
    yoffset = ((ypoints+1)/2-map.y0)*map.ystep;
    
    % Create grid
    mygrid = FT_init_grid(xpoints,ypoints,xsize,ysize,xoffset,yoffset);


end

