%--------------------------------------------------------------------------
% function [map] = FT_remove_elements_from_map(map,D)
%
% A function for Matlab which removes elements from the data defined in
% the map structure outside a given diameter, and sets them to nan.
%
% map:  mirror map in the standard structure
% D:    diameter outsiude of which points are removed [m]
%
% Charlotte Bond    03.05.2011
%--------------------------------------------------------------------------
%

function [map] = FT_remove_elements_from_map(map,D)
 
  % Define grid for all the map data
  mygrid = FT_create_grid_for_map(map);
  
  % Find all points outside the minimum radius
  outside=find(mygrid.r>D/2);
  
  % Set these elements to nan 
  map.data(outside)=nan;
  
  % remove unnecessary points (nan points) outside the valid map grid.
  Rx = round((ceil(D/map.xstep)+2)/2);
  Ry = round((ceil(D/map.ystep)+2)/2);
  if 2*Ry<mygrid.ypoints && 2*Rx<mygrid.xpoints
      x0 = round(map.x0);
      y0 = round(map.y0);
  
      new_data = map.data(y0-Ry:y0+Ry,x0-Rx:x0+Rx);
      map.data = new_data;
  end
  
  % Reassign nan values in map
  map.nan=isnan(map.data);
  map.notnan=not(map.nan);
  map = FT_recenter_mirror_map(map);

end

