%--------------------------------------------------------------------------
% function [K,nm_in,nm_out] = FT_map_knm( map, gp_in, gp_out, maxtem,err)
%
% Calculates the coupling coefficient for a beam interacting with a
% surface defined by a typical FINESSE map file
%
% map:    Map object
% gp_in:  Incoming beam parameters
% gp_out: Outgoing beam parameters
% maxtem: Maximum mode number to compute upto
% err:    Absolute error for integration routine
% 
% Output
% K:            Matrix of coupling coefficents
% nm_in,nm_out: Incoming and outgoing modes that match upto matrix K
%
% Part of the Simtools package, http://www.gwoptics.org/simtools
%
% Daniel Brown    25.11.2012
%--------------------------------------------------------------------------
%
function [K,gc] = FT_map_knm( map, gp_in, gp_out, maxtem,err, just00input)
    [gc, number_of_coeffs]=FT_init_gauss_coefficients('HG', maxtem);
    K = zeros(number_of_coeffs, number_of_coeffs);
    curr = 0;
    
    [X,Y] = FT_map_XY(map);
    
    D = map.data;
    D(isnan(D)) = 1;
    
    if map.type == 0
        if map.field == 1 || map.field == 0
            A = @(x,y) exp(4i.*pi.*FT_interp2(X,Y,D.*map.scaling,x,y,'linear')./gp_in.lambda);
        else
            A = @(x,y) exp(2i.*pi.*FT_interp2(X,Y,D.*map.scaling,x,y,'linear')./gp_in.lambda);
        end
    elseif map.type == 1
        A = @(x,y) 1-FT_interp2(X,Y,D.*map.scaling,x,y,'linear');
    elseif map.type == 2
        A = @(x,y) FT_interp2(X,Y,D.*map.scaling,x,y,'linear');
    else
        error('MapTypeError','Could not handle map type');
    end
    
    currnm = 0;
    
    if just00input == true
        maxtemin = 0;
    else
        maxtemin = maxtem;
    end
    
    for nm_in = 1:number_of_coeffs
        
            currnm = currnm + 1;
            currnm_ = 0;
            
            for nm_out = 1:number_of_coeffs

                currnm_ = currnm_ + 1;

                fprintf('Calculating %i%i->%i%i = ',gc.index1(nm_in),gc.index2(nm_in),gc.index1(nm_out),gc.index2(nm_out));
                
                K(nm_in, nm_out) = FT_knm(gp_in,gp_out,A,gc.index1(nm_in),gc.index1(nm_out), gc.index2(nm_in), gc.index2(nm_out), err, max(X));
                fprintf('%g %gi\n',real(K(nm_in,nm_out)),imag(K(nm_in,nm_out)));
                curr = curr+1;
            end
    end
end

