% Plots x axis tilt coupling into higher order modes using bayer-helms
% equations

clear all;

z = 0;
w0 = 1e-3;
lambda = 1064e-9;
zr = pi*w0^2/lambda;
q = z + 1i*zr;
gp = FT_init_gauss_param(lambda, 1, 'q',q);
gamma = logspace(-8, -2, 100);

for i=1:length(gamma)
    k00_00(i) = FT_bayer_helms_knm(gp, gp, 0,0,0,0, gamma(i), 0);
    k00_10(i) = FT_bayer_helms_knm(gp, gp, 0,0,1,0, gamma(i), 0);
    k00_20(i) = FT_bayer_helms_knm(gp, gp, 0,0,2,0, gamma(i), 0);
    k00_30(i) = FT_bayer_helms_knm(gp, gp, 0,0,3,0, gamma(i), 0);
    k00_40(i) = FT_bayer_helms_knm(gp, gp, 0,0,4,0, gamma(i), 0);
end

figure();
semilogx(gamma, abs(k00_00), gamma, abs(k00_10), gamma, abs(k00_20), gamma, abs(k00_30), gamma, abs(k00_40));
xlabel('\gamma_x (misalignment) [rad]');
ylabel('|k_{nmn''m''}|');
title(sprintf('Coupling from x tilt into higher order modes, w_0=%Gm, z=%Gm', w0, z));
legend('k_{0000}','k_{0010}','k_{0020}','k_{0030}','k_{0040}','Location','Best');