%--------------------------------------------------------------------------
% Function: [ I ] = FT_finesse_load_integration_data( filename )
%
% Loads the integration data that FINESSE outputs when using the command
%   
%   conf [component] save_integration_data 1
%
% in the kat file when using maps.
%
% Input:
%   filename: Filename of integration data e.g. bs_00_00.intdata
%
% Output:
%   I:        Struct containing various coupling coefficients
%
% Daniel Brown 21/01/2013
%--------------------------------------------------------------------------
function [ I ] = FT_finesse_load_integration_data( filename )

    baseid='FT_read_kat_output_knm';

    if (~ischar(filename))
        msgid=[baseid,':checkinarg'];
        msg='input argument must be a filename';
        error(msgid,msg);
    end
    
    [fid, result]=fopen(filename,'r');

    if (fid==-1)
        msgid=[baseid,':fileopen'];
        error(msgid,result);
    end

    not_done = true;
    I = struct('U1',[],'U2',[],'A',[],'phi',[],'N',0);
    
    N = 0;
    
    while not_done
        
        line = fgetl(fid); 

        if ~ischar(line)
            not_done = false;
        else

            vals = textscan(line,'%f');
            
            I.N= I.N + 1;
            
            I.X(I.N) = vals{1}(1);
            I.Y(I.N) = vals{1}(2);
            I.U1(I.N) = vals{1}(3) + vals{1}(4).*1i;
            I.U2(I.N) = vals{1}(5) + vals{1}(6).*1i;
            I.A(I.N) = vals{1}(7);
            I.phi(I.N) = vals{1}(8);
        end
    end
end

