%--------------------------------------------------------------------------
% Function: FT_finesse_plot_integration_data(intdata, N)
%
% Plots 2D scatter plots of the phase and magnitude of the integration 
% data, namely U1 the incoming mode, U2 the outgoing mode, and the phase
% and amplitude of the distortion
%
% Input:
%   intdata:     Structure returned by FT_finesse_load_integration_data
%   N:           Sets which points to plot, e.g. 1:N:max(size(X))
%
% Daniel Brown 21/01/2013
%--------------------------------------------------------------------------
function FT_finesse_plot_integration_data(intdata, N)

    ix=1:N:max(size(intdata.X));

    X = intdata.X(ix);
    Y = intdata.Y(ix);
    
    figure();
    subplot(1,2,1);
    Z = abs(intdata.U1(ix));
    scatter(X,Y,3,Z,'filled');
    title('Input Mode - Amplitude');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Beam Amplitude');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
    
    subplot(1,2,2);
    Z = angle(intdata.U1(ix));
    scatter(X,Y,3,Z,'filled');
    title('Input Mode - Phase');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Beam Phase');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
    
    figure();
    subplot(1,2,1);
    Z = abs(intdata.U2(ix));
    scatter(X,Y,3,Z,'filled');
    title('Output Mode - Amplitude');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Beam Amplitude');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
    
    subplot(1,2,2);
    Z = angle(intdata.U1(ix));
    scatter(X,Y,3,Z,'filled');
    title('Output Mode - Phase');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Beam Phase');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
    
    
    
    
    figure();
    subplot(1,2,1);
    Z = intdata.A(ix);
    scatter(X,Y,3,Z,'filled');
    title('Distortion amplitude');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Amplitude');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
    
    subplot(1,2,2);
    Z = intdata.phi(ix);
    scatter(X,Y,3,Z,'filled');
    title('Distortion phase');
    xlabel('x [m]');
    ylabel('y [m]');
    xlim([min(X) max(X)]);
    ylim([min(Y) max(Y)]);
    c=colorbar;
    ylabel(c,'Beam Phase');
    colormap(FT_neg_colormap);
    set(gca,'DataAspectRatio',[1 1 1]);
end

