%---------------------------------------------------------------------  
% function FT_finesse_split_photodiode(maxtem,xy)
%
% Function for to generate text lines that contain the
% HG mode beat coefficients for a split photo detectors.
% the text output of this function can be use for the
% pdtype definition of a split photodetector in the `kat.ini'
% file, see also the Finesse manual, section 4.7.3 Split 
% Photodectors.
%
% maxtem (integer): maximum mode order
% xy (integer): xy=0 for x-split, xy=1 for y-split detector
%
% Andreas Freise 25.02.2013
%---------------------------------------------------------------------  

% Description: generates split photo detectors data for kat.ini
% Keywords: photodetectors, HG, modes, Finesse, kat

function FT_finesse_split_photodiode(maxtem, xy)

  assert(maxtem>0,'maxtem must be > 0');
  assert((xy==1 || xy==0), 'xy must be 0 or 1');
  
  test=0; % Set this to one for running a numerical test
  
  % testing for presence of variable preciaion package
  mp_present=0;
  if (exist('mp.m'))
    try
      a=double(mp(1));
      if (a==1)
        mp_present=1;
      end
    catch
    end
  end
  
  if (mp_present)
    fprintf('found variable precision package\n');
  end
  
  if (test==2 && ~mp_present)
    fprintf('cannot find variable precision package. Stopping.\n')
    return
  end
  
  if (test==0 && ~mp_present && maxtem >25)
    fprintf('** Warning: results for maxtem>25 might be wrong without variable precision package.\n')
  end
  
  if (test==1)
    fprintf('performing numerical test ...\n\n');
  end
  if (test==2)
    fprintf('performing arbitrary precision test ...\n\n');
  end
  
  if (test==0)  
    if (xy==0)
      fprintf('PDTYPE x-split\n');
    else
      fprintf('PDTYPE y-split\n');
    end
  end
  
  maxtem_even=maxtem-mod(maxtem,2); % get largest even mode order
  maxtem_odd=maxtem-1+mod(maxtem,2); % get largest odd mode order
  for n1=0:2:maxtem_even
    for n2=1:2:maxtem_odd
      if (test==1)
        c_n1n2_a=FT_analytical_HG_split_diode_coeffs(n1,n2);
        c_n1n2_n=FT_numerical_HG_split_diode_coeffs(n1,n2);
        fprintf('%2d %2d: a=%.15g n=%.15g error=%.15g \n',n1,n2,c_n1n2_a, c_n1n2_n, abs(c_n1n2_a-c_n1n2_n)/max(abs(c_n1n2_a),abs(c_n1n2_n)));
      end
      if (test==2)
        c_n1n2_a=FT_analytical_HG_split_diode_coeffs(n1,n2);
        c_n1n2_n=FT_mp_analytical_HG_split_diode_coeffs(n1,n2);
        fprintf('%2d %2d: a=%.15g mp=%.15g error=%.15g \n',n1,n2,c_n1n2_a, c_n1n2_n, abs(c_n1n2_a-c_n1n2_n)/max(abs(c_n1n2_a),abs(c_n1n2_n)));
      end
      
       if (test==0)
         if (mp_present)
           c_n1n2=FT_mp_analytical_HG_split_diode_coeffs(n1,n2);
         else
           c_n1n2=FT_analytical_HG_split_diode_coeffs(n1,n2);
         end
           if (xy==0)
          fprintf('%2d x %2d x %.15g\n',n1,n2,c_n1n2);
        else
          fprintf('x %2d x %2d %.15g\n',n1,n2,c_n1n2);
        end
      end
    end
  end

  if (test==0)
    fprintf('END\n');
  end
  
  if (test==0 && ~mp_present && maxtem >25)
    fprintf('** Warning: results for maxtem>25 might be wrong without variable precision package.\n')
  end
