%---------------------------------------------------------------------  
% function c_n1n2=FT_mp_analytical_HG_split_diode_coeffs(n1,n2)
%
% Function for calculating analytical higher-order mode beat coefficients
% for an infinite sized split photo diode, see Finesse manual
% section 4.7.3 Split Photodectors. This is the variable precision
% version of the function FT_analytical_HG_split_diode_coeffs(n1,n2)
% My tests have shown errors when using double precision for n1,n2>30
%
% This function requires the variable precision package:
% http://www.mathworks.co.uk/matlabcentral/fileexchange/6446-multiple-precision-toolbox-for-matlab
% 
% This function is used by FTE_pdtype_split_detectors(maxtem)
% to produce the required data for the `kat.ini' file.
%   
% c_n1n2 (real): beat coefficient for Hermite-Gauss modes of indices n1 and n2
%
% n1 (integer): mode index of first HG mode, must be even
% n2 (integer): mode index of second HG mode, must be odd
%
% Paul Fulda, Andreas Freise 25 Feb 2013
%---------------------------------------------------------------------  

% Description: computes HG beat coefficients for split photo detectors
% Keywords: photodetectors, HG, modes,  Finesse

function c_n1n2=FT_mp_analytical_HG_split_diode_coeffs(n1,n2)
   
  assert(mod(n1,2) == 0,'n1 must be even');
  assert(mod(n2,2) ~= 0,'n2 must be odd');
  
  temp=mp(0);
  for l=0:n1/2
    for k=0:(n2-1)/2
           temp = temp + ((mp(-1.0)/4)^(l+k))*factorial((mp(double(n2))+n1-1)/2-l-k)/...
      (factorial(mp(double(l)))*factorial(mp(double(k)))*factorial(mp(double(n1))-2*l)*factorial(mp(double(n2))-2*k));

    end
  end 

  c_n1n2=double(temp*sqrt(2^(n1+n2)*factorial(n1)*factorial(n2)/pi));
