%---------------------------------------------------------------------  
% function c_n1n2=FT_numerical_HG_split_diode_coeffs(n1,n2)
%
% Function for calculating twice the integral fnm from 0 to infinity
% of two HG modes as int_0^Inf u_n1 u_n2^*
%
% Used as a check for the analytical function
% FT_analytical_HG_split_diode_coeffs(n1,n2)
%   
% c_n1n2 (real): HG beat coefficient for split photo diodes
%
% n1 (integer): mode index of first HG mode
% n2 (integer): mode index of second HG mode
%
% Paul Fulda 25 Feb 2013
%---------------------------------------------------------------------  

% Description: computes HG beat coefficients for split photo detectors
% Keywords: photodetectors, HG, modes, Finesse

function c_n1n2=FT_numerical_HG_split_diode_coeffs(n1,n2)
  
  fn1n2 = @(x) sqrt(2/pi)*sqrt(1/(2^(n1+n2)*factorial(n1)*factorial(n2)))*...
    polyval(FT_HermitePoly(n1),sqrt(2)*x).*polyval(FT_HermitePoly(n2),sqrt(2)*x)...
    .*exp(-2*x.^2);

  c_n1n2=2*integral(fn1n2,0,Inf,'AbsTol',1e-10, 'RelTol',1e-10);