%--------------------------------------------------------------------------
% function [block_idx,line_idx,mtype] =
% FT_find_mirror_in_blocks(blocks,mirror)
%
% A function for Matlab which finds a specified mirror in blocks containing
% FINESSE command lines.  The function finds a mirror defined in FINESSE as
% a mirror (m,m1,m2) or beam-splitter (bs,bs1,bs2).
%
% blcoks:       Block structures containing FINESSE command lines.
% mirror:       Name of the mirror to find.
%
% block_idx:    Index of the block the mirror is defined in.
% line_idx:     Index of the line in the block where the mirror is defined.
% mtype:        Type of mirror.
%               0: type 'm'/'bs'
%               1: type 'm1'/'bs1'
%               2: type 'm2'/'bs2'
%
% Charlotte Bond    19.02.2013
%--------------------------------------------------------------------------
%

function [block_idx,line_idx,mtype] = FT_find_mirror_in_blocks(blocks,mirror)

    baseid = 'find_mirror_in_blocks';

    % Types of mirror command
    mcommand = {'m' 'bs'};
    mtype_str = {'' '1' '2'};
    
    i=0;
    % Try to find given mirror name for each possible mirror command
    while i<=2
        j=1;
        % Check for 'm' type and 'bs' type 
        while j<=2
            
            % Find blocks/lines where mirrors are defined
            mirror_str = sprintf('%s%s',mcommand{j},mtype_str{i+1});
            [bidx,L1,L2,lines] = FT_find_element_in_all_blocks(blocks,1,mirror_str);
                        
            % Search through blocks
            b=1;
            while b<=length(bidx)
                
                block_idx = bidx(b);
                lidx = lines(L1(b):L2(b));
                
                % Search through lines
                l=1;
                while l<=length(lidx)
                    
                    line_idx = lidx(l);
                    
                    % Find mirror name defined on line
                    line_str = blocks(block_idx).txt_lines(line_idx);
                    tmp_mirror = FT_get_element_from_line(line_str,2);
                    
                    % Does it match the name of the mirror we're lookign
                    % for.  If not keep looking.
                    if strcmp(tmp_mirror,mirror)
                        mtype = i;
                        i=3;
                        j=3;
                        b=length(bidx);
                        l=length(lidx);
                    elseif i==2 && j==2 && b==length(bidx) && l==length(lidx)
                        % Error message if mirror isn't found
                        result=sprintf('Component not found: mirror "%s" not found in blocks',mirror);
                        msgid=[baseid,':checkarguments']
                        error(msgid,result);
                    end
                    l=l+1;
                end
                b=b+1;
            end
            j=j+1;
        end
        i=i+1;
    end

end

