%--------------------------------------------------------------------------
% function [num] = FT_kat_str2num(str)
%
% A function for Matlab which converts number string from a FINESSE input 
% file into a number.  This includes detecting any scaling units and 
% applying the relevant scaling (in Matlab) to the number.  The possible 
% scaling units are:
%
% f         femto       10^(-15)
% p         pico        10^(-12)
% n         nano        10^(-9)
% u         micro       10^(-6)
% m         milli       10^(-3)
% k         kilo        10^3
% M         mega        10^6
% G         giga        10^9
%
% str:      Number read as a string from a FINESSE file
%
% num:      Returned number
%
% Charlotte Bond    20.02.2013
%--------------------------------------------------------------------------
%

function [num] = FT_kat_str2num(str)

    % Possible scaling units
    units = ['f' 'p' 'n' 'u' 'm' 'k' 'M' 'G'];
    
    % Equivalent numerical scales
    scales = [1e-15 1e-12 1e-9 1e-6 1e-3 1e3 1e6 1e9];
    
    % Number of units
    num_units = length(scales);
    
    i=1;
    % Check to see if the string contains any of the scaling units
    while i<=num_units
        
        k = strfind(str,units(i));
        
        % Remove the scaling unit and convert from string to a number
        if length(k)>0
            str = FT_remove_phrase_from_string(str,units(i));
            num = str2num(str)*scales(i);
            i=num_units+1;
        elseif i==num_units
            num = str2num(str);
        end
        
        i=i+1;
        
    end

end

