%--------------------------------------------------------------------------
% function [const,block_idx] = FT_read_const_from_blocks(blocks,const_name)
%
% A function for Matlab which finds and reads the value of a FINESSE
% constant in blocks containing FINESSE command lines.
%
% blocks:       Block structures containing FINESSE lines.
% const_name:   Name of the constant.
%
% const:        Returned value of the constant.
% block_idx:    Block in which constant was found.
%
% Charlotte Bond    19.02.2013
%--------------------------------------------------------------------------
%

function [const,block_idx] = FT_read_const_from_blocks(blocks,const_name)
    
    baseid = 'read_const_from_blocks';

    % Find blocks where constant is defined
    bidx = FT_find_element_in_all_blocks(blocks,1,'const');
    bidx2 = FT_find_element_in_all_blocks(blocks(bidx),2,const_name);
    block_idx = bidx(bidx2);
                
    % Error message if the constant name isn't found in the blocks or 
    % contant declared more than once
    if length(block_idx)==0
        result=sprintf('Invalid constant name: cant find "%s" in blocks',const_name);
        msgid=[baseid,':checkarguments']
        error(msgid,result);
    elseif length(block_idx)>1
        result=sprintf('Repetition error: constant "%s" decalerd more than once in blocks',const_name);
        msgid=[baseid,':checkarguments']
        error(msgid,result);
    end
    
    % Read in constant value from block
    const = FT_read_kat_constant(blocks(block_idx),const_name); 
end

