%--------------------------------------------------------------------------
% function [maxtem] = FT_read_maxtem_from_blocks(blocks)
%
% A function for Matlab which reads the value for 'maxtem' found in blocks
% containing FINESSE command lines.  If no maxtem is declared, or maxtem is
% switched off the returned maxtem is nan.
%
% blocks:   Block structures containing FINEESE script lines.
%
% maxtem:   The value of maxtem read from blocks.
%
% Charlotte Bond    19.02.2013
%--------------------------------------------------------------------------
%

function [maxtem] = FT_read_maxtem_from_blocks(blocks)
 
    % Find block in which maxtem is defined
    block_idx = FT_find_element_in_all_blocks(blocks,1,'maxtem');

    if length(block_idx)==1
        % Find line in block in whih maxtem is defined
        line_idx = FT_find_element_in_active_block(blocks(block_idx),1,'maxtem');
        
        % Read maxtem from line
        maxtem = FT_parse_line(blocks(block_idx).txt_lines(line_idx),2);
        if strcmp(maxtem{1},'off')
            maxtem = nan;
        else
            maxtem = cell2mat(maxtem);
        end
    elseif length(block_idx)==0
        maxtem = nan;
	else
		result=sprintf('Invalid kat file: maxtem declared more than once');
		msgid=[baseid,'checkarguments'];
		error(msgid,result)
    end
end

