%--------------------------------------------------------------------------
% function [blocks] = FT_replace_const_in_blocks(blocks,const_name,const)
%
% A function for Matlab which finds a given FINESSE constant in blocks
% containing the lines for a FINESSE simulation.  The value of the constant
% changed to a new value.
%
% blocks:       Blocks containing FINESSE command lines.
% const_name:   Name of the constant to change.
% const:        New value of the constant.
%
% blocks:       Returned blocks with new value of the constant.
%
% Charlotte Bond    19.02.2013
%--------------------------------------------------------------------------
%

function [blocks] = FT_replace_const_in_blocks(blocks,const_name,const)

    % Find block in which constant is defined
    [const_old,block_idx] = FT_read_const_from_blocks(blocks,const_name);
    
    % Find line where constant is defined
    lidx = FT_find_element_in_active_block(blocks(block_idx),2,const_name);
    
    % Replace the value of the constant
    blocks(block_idx).txt_lines(lidx)={FT_replace_value_in_line(blocks(block_idx).txt_lines(lidx),3,const)};

end

