%--------------------------------------------------------------------------
% function [blocks] = FT_replace_maxtem_in_blocks(blocks,maxtem)
%
% A function for Matlab which locates the 'maxtem' command in the FINESSE
% lines contained in given blocks and replaces the set value of maxtem with
% a given value.
%
% blocks:       Blocks containing command lines for a FINESSE simulation.
% maxtem:       Value of maxtem replace current value.
%
% blocks:       Returned blocks with new value of maxtem.
%
% Charlotte Bond    19.02.2013
%--------------------------------------------------------------------------
%

function [blocks] = FT_replace_maxtem_in_blocks(blocks,maxtem)

    % Locate block where maxtem command is used
    block_idx = FT_find_text_in_all_blocks(blocks,'maxtem');
    
    if length(block_idx)~=0
        % Locate line in block where maxtem command is used
        line_idx = FT_find_element_in_active_block(blocks(block_idx),1,'maxtem');

        % Replace the value for maxtem
        blocks(block_idx).txt_lines(line_idx)={FT_replace_value_in_line(blocks(block_idx).txt_lines(line_idx),2,maxtem)};
    else
        % If maxtem command doesn't exist add it to the end of the last
        % block.
        blocks(length(blocks)) = FT_add_line_to_block(blocks(length(blocks)),sprintf('maxtem %g',maxtem));
    end

end

