%--------------------------------------------------------------------------
% function [map] =
% FT_create_astigmatic_map_rc(Rcx,Rcy,R,realsize,gridsize)
%
% A function for Matlab which creates a mirror map describing the 
% astigmatic part of a specific mirror surface.
%
% Rcx:      x-axis astigmatism [m]
% Rcy:      y-axis astigmatism [m]
% R:        Mirror radius [m]
% realsize: Real size of the mirror map (i.e. length of one side) [m]
% gridsize: Number of points for the grid representing the map, points =
%           gridsize*gridsize.
%
% map:      Map describing astigmatic surface
%
% Daniel Brown, Charlotte Bond   30.04.2013
%--------------------------------------------------------------------------
%

function [map] = FT_create_astigmatic_map_rc(Rcx,Rcy,R,realsize,gridsize)
    
    % Create astigmatic map
    map = FT_create_individual_Znm_map(0,0,0,R,realsize,gridsize);
    
    mygrid = FT_create_grid_for_map(map);
    
    % Astigmatic surface in nm
    if Rcx ~= 0
        map.data = map.data + (Rcx - sign(Rcx).*sqrt(Rcx.^2-mygrid.X.^2))/1e-9;
    end
    
    if Rcy ~= 0
        map.data = map.data + (Rcy - sign(Rcy).*sqrt(Rcy.^2-mygrid.Y.^2))./1e-9;
    end

end

