%--------------------------------------------------------------------------
% function [map] = FT_write_curved_map(Rc,R,realsize,gridsize)
%
% A function which creates a curved surface of radius of curvature Rc and
% stores it in the standard map structure.
%
% Rc:       The radius of curvature of the surface
% R:        Mirror radius [m]
% realsize: Real size of the mirror map (i.e. length of one side) [m]
% gridsize: Number of points for the grid representing the map, points =
%           gridsize*gridsize.
%
% map:      Returned map describing curved surface
%
% Daniel Brown, Charlotte Bond    22.04.2013
%--------------------------------------------------------------------------
function [map] = FT_create_curved_map(Rc,R,realsize,gridsize)

    map = FT_create_individual_Znm_map(0,0,0,R,realsize,gridsize);
    mygrid = FT_create_grid_for_map(map);
    
    Z = (Rc - sign(Rc).*sqrt(Rc.^2-mygrid.r_squared));
    map.data(map.notnan) = Z(map.notnan)./map.scaling;

end

