%--------------------------------------------------------------------------
% function [zmap,zc] = FT_create_individual_Znm_map(n,m,A,r,realsize,gridsize)
%
% A function for Matlab which creates a mirror map structure representing
% the surface defined by a particular zernike polynomial, Znm.
%
% n,m:      Indices of particular polynomial
% A:        Zernike polynomial amplitude [nm]
% R:        Surface radius [m]
% realsize: Real size of the map [m]
% gridsize: Number of points for map grid
%
% zmap:     Returned zernike map
%
% Charlotte Bond    17.01.2013
%--------------------------------------------------------------------------
%

function [zmap] = FT_create_individual_Znm_map(n,m,A,R,realsize,gridsize)
    
    % Create zernike coefficient structure
    zc = FT_init_zernike_coefficients(n);
    
    % Update with the values for the particular polynomial
    zc = FT_update_zernike_coefficient(zc,n,m,A);
    
    % Map name
    mapname = sprintf('zmap_Z%g%g',n,m);
    
    % Create zernike map
    zmap = FT_create_synthetic_zernike_map(zc,'original',realsize,gridsize,R,mapname);
    
end

