%--------------------------------------------------------------------------
% function [map] =
% FT_create_lens_map(gridsize,realsize,R,focallength)
%
% A function for Matlab which creates a map in the standard structure
% describing a lens with a given focal length.  The map data describes the
% optical path length of a lens with such a focal length.
%
% gridsize:     Number of points for the rows and columns, i.e. will make a
%               grid of gridsizexgridsize points.
% realsize:     Map dimensions [m]
% R:            Radius of the lens [m]. Points outside the radius are set
%               to nan.
% focallength:  Focal length of the lens [m]
%
% Charlotte Bond    14.03.2013
%--------------------------------------------------------------------------
%

function [map] = FT_create_lens_map(gridsize,realsize,R,focallength)
    
    mygrid = FT_init_grid(gridsize,gridsize,realsize,realsize,0,0);
    x0 = (mygrid.xpoints+1)/2;
    y0 = (mygrid.ypoints+1)/2;
    
    % Calculate optical path length
    OPL = (-1/(2*focallength)) * mygrid.r_squared;
    
    % Set all points outside the lens radius to nan
    idx = find(mygrid.r>R);
    OPL(idx)=nan;

    % Phase map
    type = 0;
    % Only affect transmitted light
    field = 2;
    
    name = 'lens_map';
    
    % Write map
    map = FT_new_surface_map(name,OPL,type,field,x0,y0,mygrid.xstep,mygrid.ystep,1);

end

