%--------------------------------------------------------------------------
% function [map] = FT_create_tilted_map(xbeta,ybeta,R,realsize,gridsize)
%
% A function for Matlab which creates a tilted mirror map and stores it in 
% the standard map structure.  
%
% xbeta/ybeta:  Angles describing the tilt [rad]
% R:            Mirror map radius [m]
% realsize:     Real size of the map [m]
% gridsize:     Number of points (i.e. cols and rows) 
%
% map:          Returned map
%
% Charlotte Bond    17.01.2013
%--------------------------------------------------------------------------
%
function [map] = FT_create_tilted_map(xbeta,ybeta,R,realsize,gridsize)

    % Calculate amplitude of the tilt in nm
    A11 = 1e9*R*tan(xbeta);
    A1n1 = 1e9*R*tan(ybeta);
    
    % Initiate zernike coefficients structure
    zc = FT_init_zernike_coefficients(1);
    
    % Update zc with tilt amplitudes
    zc = FT_update_zernike_coefficient(zc,1,-1,A1n1);
    zc = FT_update_zernike_coefficient(zc,1,1,A11);
    
    % Map name
    mapname = 'tilted_map';
    
    % Create zernike map
    map = FT_create_synthetic_zernike_map(zc,'original',realsize,gridsize,R,mapname);
    map.name = mapname;

end

