%--------------------------------------------------------------------------
% function [profile] = FT_plot_map_cross_section(map,option,offset)
%
% A function for Matlab which takes a map in the standard FT structure,
% selects a cross section along the x or y axis and plots this cross
% section.
%
% map:      Original map in standard FT structure.
% option:   'x':    Take data horizontally, i.e. over entier range 
%                   of x values for one y value.
%           'y':	Take data vertically, i.e. over entire range of
%                   y values for one x value.
% offset:   Offset from x0 or y0, the index where the line of data is taken 
%           from.  If the offset is 0 the data is taken across the centre 
%           (round(x0) or round (y)).
%  
% profile:  Structure containg 1D surface data 
%  
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    09.10.2013
%--------------------------------------------------------------------------
%

function [profile] = FT_plot_map_cross_section(map,option,offset)

    % Select cross section
    profile = FT_select_1D_map_data(map,option,offset);
    
    % Plot cross section
    FT_plot_surface_profile(profile,0);

end

