%--------------------------------------------------------------------------
% function [map_out,A,xbeta,ybeta] = FT_remove_zernike_tilt_from_map(map)
%
% A function for Matlab which takes a map in the usual structure (see
% FT_new_surface_map.m) and removes any tilt from the surface by 
% calculating the overlap between the Zernike tilt terms and the map 
% surface.
%
% map:      Input map
%
% map_out:  Output map with tilt removed
% A:        Amplitude of the Zernike tilt terms removed [nm]
%           A(1) = amplitude of Z1-1 (odd polynomial, tilt in y-direction)
%           A(2) = amplitude of Z1+1 (even polynomial, tilt in x-direction)
% xbeta/ybeta:  Equivalent tilt in radians removed from the surface 
%
% Charlotte Bond    30.01.2013
%--------------------------------------------------------------------------
%

function [map_out,A,xbeta,ybeta] = FT_remove_zernike_tilt_from_map(map)

    % Zernike map convolution up to order 1 (don't save the data)
    zc = FT_zernike_map_convolution(map,1,0);
        
    map_out = map;
    R = map.xstep*FT_find_map_radius(map);
    
    % Remove Z1-1 term
    A(1) = FT_get_zernike_coefficient(zc,1,-1);
    map_out = FT_remove_zernike_polynomial_from_map(map_out,1,-1,A(1));
    ybeta = atan(A(1)*map.scaling/R);
    
    % Remove Z1+1 term
    A(2) = FT_get_zernike_coefficient(zc,1,1);
    map_out = FT_remove_zernike_polynomial_from_map(map_out,1,1,A(2));
    xbeta = atan(A(2)*map.scaling/R);

	% In nm
    A = 1e9*map.scaling*A;
end

