%--------------------------------------------------------------------------
% function [data] = FT_select_1D_data(data_2D,option,line_idx)
%
% Matlab function which takes a 2D array of data and selects and returns 
% one line of the data.
%
% data_2D:          Original 2D data
% option:           'x':			Take data horizontally, i.e. over 
%                                   entier range of x values for one y 
%                                   value.
%                   'y':			Take data vertically, i.e. over entire
%                                   range of y values for one x value.
% line_idx:         x or y (constant) index for line of data required.
%
% data:             Returned 1D data taken from the original data array.
%
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    19.12.2011
%--------------------------------------------------------------------------
%


function [data] = FT_select_1D_data(data_2D,option,line_idx)

    baseid = 'select_1D_data';
     
    % Error messages
    if (strcmp(option,'x')==0 && strcmp(option,'y')==0)
        result='Invalid option: should be either "x" or "y"';
        msgid=[baseid,':checkarguments']
        error(msgid,result);
    end
     
    [rows,cols] = size(data_2D);
    
    % Select one line of data
    if strcmp(option,'x')
        data_1D(1:cols) = data_2D(line_idx,:);
    elseif strcmp(option,'y')
        data_1D(1:rows) = data_2D(:,line_idx);
    end
    
    data = data_1D;
    
end

