%--------------------------------------------------------------------------
% FTE_map_preparation_05.m
%
% An example script for Matlab demonstrating the use of some of the tools
% required to read and prepare maps for FINESSE.  05 of 06 example scripts
% where the data is read, prepared and curvature, offset and tilt is 
% removed.
% 
% Charlotte Bond    30.01.2013
%--------------------------------------------------------------------------
%

clear all;

% Example map
filename = 'CVI1-S1-BC.asc';

% Read map in .asc format
map = FT_read_zygo_map(filename,2)

% Recnetering the map
map = FT_recenter_mirror_map(map);

% Removing invalid elements
map = FT_remove_elements_outside_map(map);

% Removing zernike curvature
[map,A2,Rc] = FT_remove_zernike_curvatures_from_map(map,'constant');

% Map radius
R = map.xstep*FT_find_map_radius(map);
 
% Remove zernike offset
[map,A0] = FT_remove_zernike_offset_from_map(map);

% Remove zernike tilt
[map,A1,xbeta,ybeta] = FT_remove_zernike_tilt_from_map(map);

% Plot map
FT_plot_mirror_map(map,0)

% Output removed parameters
fprintf('--------------------------------------------------------------\n')
fprintf('Mirror diameter:               %g cm \n',2*R*100)
fprintf('Zernike amplitude (Z20):       %g nm \n',A2)
fprintf('Equivalent ROC:                %g m \n',Rc(1))
fprintf('Zernike amplitude (Z00):       %g nm \n',A0)
fprintf('Zernike amplitude (Z1-1):      %g nm \n',A1(1))
fprintf('Equivalent tilt (ybeta):       %g urad \n',ybeta*1e6)
fprintf('Zernike amplitude (Z11):       %g nm \n',A1(2))
fprintf('Equivalent tilt (xbeta):       %g urad \n',xbeta*1e6)
fprintf('--------------------------------------------------------------\n')
