%--------------------------------------------------------------------------
% function [mirror] = FT_add_random_surface_map(mirror,map,mygrid,lambda)
%
% A function for Matlab which adds a random surface map to the grid
% defining the surface of a mirror, defined in the standard mirror
% structure.  The map represents random mirror surface distortions.
%
% mirror:       structure defining the mirror surface and properties
% map:          a structure defining a distorted surface
% mygrid:       structure defining a grid for use in FFTs
% lambda:       wavelength
%
% Charlotte Bond    30.10.2010
%--------------------------------------------------------------------------
%

function [mirror] = FT_add_random_surface_map(mirror,map,mygrid,lambda)
    
    % Temporary map bases
    map_base=zeros(mygrid.xpoints,mygrid.ypoints,'double');
      
    map_base=map.scaling*map.data;
      
    % Surface maps
    phase_refl_front =             -2.0 * map_base;
    phase_refl_back  =   2.0 * mirror.n * map_base;
    phase_trans      = (mirror.n - 1.0) * map_base;
  
    k=2*pi/lambda;

    % Phase maps
    mirror.map_refl_front = mirror.map_refl_front .*  exp(-1i * k * phase_refl_front);
    mirror.map_refl_back  = mirror.map_refl_back  .*  exp(-1i * k * phase_refl_back);
    mirror.map_trans      = mirror.map_trans      .*  exp(-1i * k * phase_trans);  
    
    % Flip back map horizontally
    mirror.map_refl_back = mirror.map_refl_back(:,size(mirror.map_refl_back,1):-1:1);
 
end