#---------------------------------------------------------------------------
# help_data_compiler.py
# Author: Robert Unwin - 19.07.10
# A python program which compiles data from the SimTools package,
# to be used by the Finesse FT_help function
#---------------------------------------------------------------------------

import os, re, datetime # imports all relevant modules

basedir = os.getcwd() # specifies the base directory to perform scan in

stem = re.split('\W+',basedir) # split basedir string into a list
forb = ['.svn','new'] # lists forbidden categories

numero = 1 # defines entry in array
info = [] # (INDEXING) there exists an information array: [number, file name, path, description, keywords, categories]

for (dirpath, dirnames, filenames) in os.walk(basedir): # scan through all files in specified directory, down

	for file in filenames: # for every file in the list of filenames
		address = os.path.join(dirpath, file) # compose an address for each file
		kats = re.split('\W+',dirpath) # split directory path string into seperate entries
		
		Y = True # define a flag to test which files are to be opened, using the following criteria...
		if file[:2] != 'FT': Y = False # ...filename must begin with 'FT' prefix...
		if file[-2:] != '.m': Y = False # ...file must be an M-file...
		for place in kats:
			for type in forb:
				if place == type: Y = False # ...file must not be in a forbidden category.
		
		if Y: # if file matches criteria:
			keys = [] # create/refresh a keywords list
			desc = [] # create/refresh an empty array for description text
			f = open(address,'r') # open the file
			S = True
			Q = True # there exists 2 boolean values for flagging
			name = file[:-2] # store the filename as a name without the '.m' suffix
			
			for line in f: # run through each line of the file
				synopsis = re.search('(%+)(.*)(D|d)(escription)(|s)( *)(:)(\W*)',line)
				# perform sophisticated regular expression search to find description header
				if synopsis is not None:
					S = False
					m = synopsis.end() # obtain the end position of description header
					K = line[m:] # obtain string after header
					K=K.rstrip('\r\n')
					if K != '': # providing the string is NOT EMPTY...
						desc.append(K) # append line of text to array
					else: desc.append("(no text)") # otherwise notify user of the lack of text
				
				mark = re.search('(%+)(.*)(K|k)(eyword)(|s)( *)(:)(\W*)',line)
				# perform sophisticated regular expression search to find keyword marker
				if mark is not None: # if the line contains such a marker
					Q = False # unflag the file
					n = mark.end() # obtain the end position of the marker
					L = line[n:] # obtain the string after the marker
					if L != '': # providing the string is NOT EMPTY...
						line_keys = re.split('\W+',L) #...split into a list of keywords (seperated by any symbol or whitespace)
						for word in line_keys: # for each element in the list
							if word != "": keys.append(word) # providing it is not empty, add it to the official keys list
					else: keys.append("(no keywords)") # but if string was EMPTY inform of the lack of keywords
			if S: desc = ['(no description)'] # if file is still flagged after process, inform of the lack of a header
			if Q: keys = ['(no marker)'] # if file is still flagged after process, inform of the lack of a marker
			
			#cats = ['all'] # there exists a categroy array, containing the element 'all'
			cats = [] # there exists a categroy array, containing the element 'all'
			for place in kats: # for each entry in directory path list (after splitting)...
				W = True # define a Boolean value for flagging
				for space in stem: # for each entry in stem (basedir)...
					if place == space: W = False #...sift through entries and unflag if entries are similar
				if W: cats.append(place) # if entry is still flagged, append to category list
	
			entry = [numero, name, dirpath, desc, keys, cats] # define the data entry list
			info.append(entry) # add entry into information array
			numero += 1 # increment array value by 1
			f.close() # close f
			
key_list = [] # (KEY RESHUFFLE) there exists an empty list
info_key = [] # there exists an empty info array

for [numero, name, dirpath, desc, keys, cats] in info: # read through each entry in the acquired data
	for word in keys: # for each keyword in the key list
		Q = True # define Boolean for flagging
		if key_list == []: key_list.append(word) # if list is empty, add first keyword
		for key in key_list: # read through each element of the key list
			if key == word: Q = False # if word is already in key list, un-flag word
		
		if Q: key_list.append(word) # if Q is still flagged, append keyword to list

numerk = 1 # new counting number

for key in key_list: # read through list of unique keywords
	key_file = [] # refresh key file list
	for [numero, name, dirpath, desc, keys, cats] in info: # read through each entry in the acquired data
		for word in keys: # read through each word in keys
			if word == key: # if the current keyword is used to describe this entry in info
				key_file.append(numero) # append filename to list

				
	key_entry = [numerk,key,key_file] # define entry for array
	info_key.append(key_entry) # append entry to array
	numerk += 1

cat_list = [] # (CATEGORY RESHUFFLE) there exists an empty list
info_cat = [] # there exists an empty info array

for [numero, name, dirpath, desc, keys, cats] in info: # read through each entry in the acquired data
	for word in cats: # for each category in the cat list
		Q = True # define Boolean for flagging
		if cat_list == []: cat_list.append(word) # if list is empty, add first category
		for cat in cat_list: # read through each element of the cat list
			if cat == word: Q = False # if word is already in cat list, un-flag word
		
		if Q: cat_list.append(word) # if Q is still flagged, append category to list

numerc = 1 # new counting number

for cat in cat_list: # read through list of unique categories
	cat_file = [] # refresh cat file list
	for [numero, name, dirpath, desc, keys, cats] in info: # read through each entry in the acquired data
		for word in cats: # read through each word in cats
			if word == cat: # if the current category is used to describe this entry in info
				cat_file.append(numero) # append category to list
				
	cat_entry = [numerc,cat,cat_file] # define entry for array
	info_cat.append(cat_entry) # append entry to array
	numerc += 1

g = open('./help_info_out.m','w')
h = open('./help_info_key.m','w')
i = open('./help_info_cat.m','w') # open info output files

date = str(datetime.datetime.now()) # obtain date & time of update
print "Base Directory: " + basedir
print date

g.write('%---------------------------------------------------------------------\n')
g.write('% Data File: help_info_out\n')
g.write('% Stores information about all functions in "' + str(basedir) + '"\n')
g.write('% Last Updated: ' + date + '\n')
g.write('%---------------------------------------------------------------------\n')

h.write('%---------------------------------------------------------------------\n')
h.write('% Data File: help_info_key\n')
h.write('% Stores keyword information about all functions in "' + str(basedir) + '"\n')
h.write('% Last Updated: ' + date + '\n')
h.write('%---------------------------------------------------------------------\n')

i.write('%---------------------------------------------------------------------\n')
i.write('% Data File: help_info_cat\n')
i.write('% Stores category information about all functions in "' + str(basedir) + '"\n')
i.write('% Last Updated: ' + date + '\n')
i.write('%---------------------------------------------------------------------\n')
# write the headers to all 3 output files, including date and time

print ''
# all data
for [numero, name, dirpath, desc, keys, cats] in info: # write info in matlab format
	print ([numero, name, dirpath, desc, keys, cats]) # print to screen data entries
	place = "index(" + str(numero) + ")." # assemble data construct name
	g.write(place + "name = '" + str(name) + "';\n") # give data entry file name
	g.write(place + "path = '" + str(dirpath) + "';\n") # give data entry path
	g.write(place + "description = [")
	m = 1 # defines a counting number
	n = len(desc) # defines the limit of the count
	for line in desc: # construct an array of description lines for matlab
		g.write("{'" + line + "'}")
		if m != n: g.write(",") # providing entry is not the last, add a comma
		m += 1 # increment m
	g.write("];\n")
	g.write(place + "keys = [")
	m = 1 # redefine counting values
	n = len(keys)
	for key in keys: # construct an array of keyword strings for matlab
		g.write("{'" + key + "'}")
		if m != n: g.write(",") # repeat method above
		m += 1
	g.write("];\n")
	g.write(place + "cats = [")
	m = 1 # redefine...
	n = len(cats)
	for cat in cats: # construct an array of category strings for matlab
		g.write("{'" + cat + "'}")
		if m != n: g.write(",") # repeat...
		m += 1
	g.write("];\n")

print ''
# keyword data
for [numerk,key,key_file] in info_key: # write key info in matlab format
	print ([numerk,key,key_file]) # print data to screen
	place = "key(" + str(numerk) + ")." # assemble data construct name
	h.write(place + "word = '" + str(key) + "';\n") # give data entry keyword
	h.write(place + "files = " + str(key_file) + ";\n") # data entry list of files (as a number array)

print ''
# category data
for [numerc,cat,cat_file] in info_cat: # write category info in matlab format
	print ([numerc,cat,cat_file]) # print data
	place = "category(" + str(numerc) + ")." # construct name
	i.write(place + "word = '" + str(cat) + "';\n") # category word
	i.write(place + "files = " + str(cat_file) + ";\n") # category file list (number array)

g.close()
h.close()
i.close() # close all output files
